@@ -166,14 +166,30 @@ def deepcopy(file_list, folder, replace = None):
     if replace:
         filesId = FileList.getSignature(file_list)
         sedID = replace.getSignature()
-        sedUpdated = Cache.read("sed-%s-%s" % (filesId, sedID))
+        filesInfo = Cache.read("sed-%s" % filesId)
 
-        if not sedUpdated:
+        sedUpdated = True
+
+        if filesInfo:
+            lastSed = filesInfo.split('\n')[-1]
+            lastSed = lastSed.split(':')[0]
+
+            if lastSed == sedID:
+                sedUpdated = False
+            
+            filesInfo += "\n"
+        else:
+            filesInfo = ""
+
+
+
+        if sedUpdated:
             forceRefresh = True
-            Cache.write("sed-%s-%s" % (filesId, sedID), "%s" % int(time.time()))
-
+            Cache.write("sed-%s" % (filesId), "%s%s:%s" % (filesInfo, sedID, int(time.time())))
 
     
+        
+    
     for (file, basepath) in file_list:
         
         if basepath:
